@@ -548,6 +548,33 @@ flush(stderr()); flush(stdout())
 
 
 
+cleanEx()
+nameEx("iscube")
+### * iscube
+
+flush(stderr()); flush(stdout())
+
+### Name: iscube
+### Title: Functions to isolate cube points from 2-level fractional
+###   factorial design with center and / or star points
+### Aliases: iscube isstar pickcube
+### Keywords: design array
+
+### ** Examples
+
+  ## purely technical example, not run because FrF2 not loaded
+  ## Not run: 
+##D   plan <- FrF2(16,5, factor.names=c("one","two","three","four","five"), ncenter=4)
+##D   iscube(plan)
+##D   plan2 <- ccd.augment(plan)
+##D   iscube(plan2)
+##D   isstar(plan2)
+##D   pickcube(plan2)
+##D   
+## End(Not run)
+   
+
+
 cleanEx()
 nameEx("lm.design")
 ### * lm.design
